# RPG
Pacote Python com as minhas ferramentas de RPG

- **3.0.0** - PF2
  - Alteração do parâmetro `.defesa_base` para `.defesa_monstro_base` para deixar mais claro seu uso
  - Alteração do import do módulo `calcula_proficiencia` para `proficiencia` pois ganhou outra função: `aumentar_proficiencia` 
  - Lista de skills em Data
  - Classe de PC para representar um personagem
- **2.2.3** - Inclusão dos danos só de rolamento no PF2
- **2.2.2** - Inclusão de valor do ataque do ataque atual como propriedade em PF2
- **2.2.1** - Correção no cálculo de save do PF2
- **2.2.0** - Inclusão do submódulo de pf2
- **2.1.2** - Correção na representação de dado
- **2.1.0** - Correção de bug
- **2.0.0** - Alteração na classe Baralho
- **1.0.0** - Lançamento